package blusci.hilfsklassen;

import java.io.File;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.PrintWriter;
import java.io.BufferedReader;
import java.io.IOException;
import java.util.Vector;

 /**
 *  <h4>Dateioperationen.java</h4>
 *
 *  Copyright (C) 2013 Guido Kramann<br/>
 *  kramann@fh-brandenburg.de<br/>
 *  http://www.kramann.info<br/>
 *  <br/>
 *  <p>  
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  </p>
 *  <p>
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *  </p>
 *  <p>
 *  You should have received a copy of the GNU General Public License
 *  along with this program (gpl.html).  If not, see http://www.gnu.org/licenses/.
 *  </p>
 */
public class Dateioperationen
{
    

    /**Überprüft, ob der als String übergebene absolute Pfad als Datei oder Verzeichnis
       existiert (true), oder nicht (false).*/
    public boolean pruefeObDateiExistiert(String absoluter_pfad)
    {
        try
        {
            File file = new File(absoluter_pfad);
            if(file.exists())
                return true;
        }
        catch(Exception eee)
        {
            return false;
        }
        return false;
    }

    /**Überprüft, ob der als String übergebene absolute Pfad auf ein Verzeichnis
       verweist.*/
    public boolean pruefeObPfadVerzeichnisIst(String absoluter_pfad)
    {
        if( pruefeObDateiExistiert(absoluter_pfad)==false )
            return false;

        try
        {
            File file = new File(absoluter_pfad);
            if(file.isDirectory())
                return true;
        }
        catch(Exception eee)
        {
            return false;
        }
        return false;
        
    }

    
   
    /**Liefert den Pfad, in dem das jar-File liegt, in welchem u.a. die vorliegende
       Klasse mit gespeichert ist.*/
    public String getJarLibraryPfad()
    {
        String pfad = Dateioperationen.class.getProtectionDomain().getCodeSource().getLocation().getPath();  
        //Jar-File-Name entfernen:
        int i = pfad.length()-1;
        while(pfad.charAt(i)!='/')
            i--;
        pfad = pfad.substring(0,i);
        return pfad;
    }

    /**Lädt die Zeilen einer Datei*/
    public   String[] ladeZeilen(String dateiname)
    {
        String[] ergebnis = null;
        Vector<String> vektor;
        File datei = new File(dateiname);
        if(datei.exists()==false)
            return null;

        try
        {
            vektor = new Vector<String>();

            FileReader meinLeser = new FileReader( new File(dateiname) );
            BufferedReader pufferleser  = new BufferedReader(meinLeser);

            String zeile = pufferleser.readLine();
            while( zeile!=null )
            {
                vektor.add(zeile);
                zeile = pufferleser.readLine();
            }
            meinLeser.close();
            ergebnis = (String[])vektor.toArray(new String[0]);
        }
        catch(IOException e) 
        { 
            return null;
        }        
        return ergebnis;
    }

    /**Liefert eine Datei als String*/
    public   String ladeText(String dateiname)
    {
        StringBuffer ergebnis = new StringBuffer();
        File datei = new File(dateiname);
        if(datei.exists()==false)
            return null;

        try
        {
            FileReader meinLeser = new FileReader( new File(dateiname) );
            BufferedReader pufferleser  = new BufferedReader(meinLeser);

            int zeile = pufferleser.read();
            while( zeile!=-1 )
            {
                ergebnis.append((char)zeile);
                zeile = pufferleser.read();
            }
            meinLeser.close();
            return ergebnis.toString();
        }
        catch(IOException e) 
        { 
            return null;
        }        
    }

    /**Speichert eine Datei als String*/
    public   void speichern(String dateiname, String text)
    {
        try
        {
            File              meinFile = new File(dateiname);
            FileWriter   meinSchreiber = new FileWriter(meinFile);
            PrintWriter  meinPrinter   = new PrintWriter( meinSchreiber );            
//NEU:
//            PrintWriter  meinPrinter   = new PrintWriter( meinFile,"UTF-8" );            
            meinPrinter.print(text);            
            meinPrinter.close();   
        }
        catch(IOException e)
        {
            System.out.println(e.getMessage());
        }
    }

    /**Speichert eine Datei als String*/
    public   void speichernUTF8(String dateiname, String text)
    {
        try
        {
            File              meinFile = new File(dateiname);
            FileWriter   meinSchreiber = new FileWriter(meinFile);
//            PrintWriter  meinPrinter   = new PrintWriter( meinSchreiber );            
//NEU:
            PrintWriter  meinPrinter   = new PrintWriter( meinFile,"UTF-8" );            
            meinPrinter.print(text);            
            meinPrinter.close();   
        }
        catch(IOException e)
        {
            System.out.println(e.getMessage());
        }
    }

    public   void speichernUTF8(String dateiname, String[] text)
    {
        try
        {
            File              meinFile = new File(dateiname);
            FileWriter   meinSchreiber = new FileWriter(meinFile);
//            PrintWriter  meinPrinter   = new PrintWriter( meinSchreiber );            
//NEU:
            PrintWriter  meinPrinter   = new PrintWriter( meinFile,"UTF-8" );            
//            meinPrinter.print(text);            
            for(int i=0;i<text.length;i++)
                meinPrinter.println(text[i]);            
            meinPrinter.close();   
        }
        catch(IOException e)
        {
            System.out.println(e.getMessage());
        }
    }


   
    /**Speichert ein 1d-String-Array als Text*/
    public   void speichern(String dateiname, String[] text)
    {
System.out.println("DOKUMENT SPEICHERN");
        try
        {
            File              meinFile = new File(dateiname);
            FileWriter   meinSchreiber = new FileWriter(meinFile);
            PrintWriter  meinPrinter   = new PrintWriter( meinSchreiber );            
//NEU:
//            PrintWriter  meinPrinter   = new PrintWriter( meinFile,"UTF-8" );            
            for(int i=0;i<text.length;i++)
                meinPrinter.println(text[i]);            
            meinPrinter.close();   
        }
        catch(IOException e)
        {
System.out.println("ERROR");
            System.out.println(e);
        }
    }
 
    public String[] alleDateien(String pfad)
    {
        File verz = new File(pfad);
        File[] dateien = verz.listFiles();
        
        int anz=0;
        if(dateien!=null && dateien.length>0)
        {
          for(int i=0;i<dateien.length;i++)
          {
              if(!dateien[i].isDirectory())
                  anz++;
          }
        }         
        String[] erg = new String[anz];

        anz=0;
        if(dateien!=null && dateien.length>0)
        {
          for(int i=0;i<dateien.length;i++)
          {
              if(!dateien[i].isDirectory())
              {
                  erg[anz]=dateien[i].getName();
                  anz++;
              }                  
          }
        }         
        return erg;
    }
    
    public static void main(String[] args)  
    {
        System.out.println("Testen von kramann.hilfsklassen.Dateioperationen");
        Dateioperationen datei = new Dateioperationen();

        System.out.println("Existiert /home/knoppix?:"+datei.pruefeObDateiExistiert("/home/knoppix"));
        System.out.println("Ist /home/knoppix ein Verzeichnis?:"+datei.pruefeObPfadVerzeichnisIst("/home/knoppix"));
        System.out.println("Existiert /home/knoppix/xyz.txt?:"+datei.pruefeObDateiExistiert("/home/knoppix/xyz.txt"));
        System.out.println("Existiert /mnt-system/autorun.bat?:"+datei.pruefeObDateiExistiert("/mnt-system/autorun.bat"));
        System.out.println("Ist /mnt-system/autorun.bat ein Verzeichnis?:"+datei.pruefeObPfadVerzeichnisIst("/mnt-system/autorun.bat"));        
    }

}
